@@ -272,12 +272,12 @@ void cmd_print(void)
 	
 	/* ps */
 	if (Ret == 1) {
-		strcpy(str, "NoName.ps");
+		strcpy(str, "Untitle.ps");
 		ps = 1;
 	}
 	/* eps */
 	else if (Ret == 0) {
-		strcpy(str, "NoName.eps");
+		strcpy(str, "Untitle.eps");
 		ps = 0;
 	}
 	/* CANCEL */
@@ -286,9 +286,14 @@ void cmd_print(void)
 	}
 #endif
 
+	sprintf(str, "%s\\Untitle.ps", sagcad_user.CadPath);
+	//char *win_command;
+	//win_command = g_locale_from_utf8(str, -1, NULL, NULL, NULL);
+	//g_print("win_command = [%s]\n", win_command);
+	//strcpy(str, win_command);
+	//g_free(win_command);
 
-
-	sprintf(str, "%s/NoName.ps", sagcad_user.CadPath);
+	
 	Ret = save_file_name_get(str);
 	/* ファイルの選択をキャンセル */
 	if (Ret == -1 || str == NULL) {
@@ -299,8 +304,13 @@ void cmd_print(void)
 		PostScript(str);
 	}
 
+#ifdef G_OS_WIN32
+	char *win_command;
 
-
+	win_command = g_locale_from_utf8(str, -1, NULL, NULL, NULL);
+	ShellExecute(0, "Open", win_command, "", "", 1); 	
+	g_free(win_command);
+#else
 	/* Editor command */
 	strcpy(path, sagcad_user.print_command);
 	replace(path, "&", "");
@@ -308,15 +318,14 @@ void cmd_print(void)
 	if (strstr(path, "%s") != NULL) {
 		replace(path, "%s", str);
 	}
-//	else {
-//		sprintf(path , "%s %s", sagcad_user.editor_command, FileName);
-//	}
 
 	sprintf(command, "%s &", path);
 	g_print("%s\n", command);
 	system(command);
+#endif
 
 
+	
 #ifdef OLD
 	sprintf(command,  _("The file saved. [%s]\n") , str);
 	Ret = MsgBox("印刷 / GhostView", command,  _("Which does it execute?") , "GhostView",  _("Print") , "終了");
@@ -980,8 +989,6 @@ int save_file_name_get(char *save_filename)
 	// GTK < 2.8 code...
  	g_print("GTK < 2.8\n");
 #endif
-	//gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
-	
 	
 	strcpy(path, save_filename);
 	cutFileName(path);
@@ -1010,6 +1017,7 @@ int save_file_name_get(char *save_filename)
 int read_file_name_get(char *read_filename)
 {
 	GtkWidget *dialog;
+	char path[1024];
 	gint ret = -1;
 	
 	dialog = gtk_file_chooser_dialog_new ("Open File",
@@ -1019,6 +1027,10 @@ int read_file_name_get(char *read_filename)
 						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 						NULL);
 	
+	strcpy(path, read_filename);
+	cutFileName(path);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), path);
+	
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
 		char *filename;
 		
@@ -1145,22 +1157,6 @@ void cmd_rename(void)
 	char str[256];
 	int Ret;
 
-	if (Undo_index != 0) {
-		//                                                                          1     0        -1
-		Ret = MsgBox("SagCAD", _("A drawing is changed!") , _("Does it save?") , "Yes", "No", "Cancel");
-		/* Yes : (Save) */
-		if (Ret == 1) {
-			cmd_save();
-		}
-		/* No : (No Save) */
-		else if (Ret == 0) {
-		}
-		/* Cancel : (return) */
-		else {
-			return;
-		}
-	}
-
 	strcpy (str, NowFile);
 	Ret = save_file_name_get(str);
 	/* ファイルの選択をキャンセル */
@@ -1182,14 +1178,11 @@ void cmd_rename(void)
 		else if(strstr(str, ".dxf") != NULL || strstr(str, ".DXF") != NULL) {
 			DxfFileSave(locale_str);
 		}
-
 		strcpy(NowFile, str);
 		/* タイトルを設定 */
 		SetTitle(NowFile);
-
 		undo_buttun(0);
 		redo_buttun(0);
-
 		/* アンドゥを削除 */
 		undo_list_all_free();
 	}
@@ -1204,7 +1197,6 @@ void cmd_save(void)
 	char *locale_str;
 	char str[256];
 
-
 	strcpy (str, NowFile);
 	locale_str = g_locale_from_utf8(str, -1, NULL, NULL, NULL);
 	if (locale_str == NULL) {
@@ -1220,16 +1212,12 @@ void cmd_save(void)
 		else if(strstr(str, ".dxf") != NULL || strstr(str, ".DXF") != NULL) {
 			DxfFileSave(locale_str);
 		}
-
 		/* アンドゥを削除 */
 		undo_list_all_free();
-
 		/* タイトルを設定 */
 		SetTitle(NowFile);
-
 		undo_buttun(0);
 		redo_buttun(0);
-
 	}
 	return;
 }
