@@ -68,13 +68,14 @@ extern "C" {
  */
 
 gint view_port_set(gdouble vx1, gdouble vy1, gdouble vx2, gdouble vy2);
+gint world_window_set(gdouble wx1, gdouble wy1, gdouble wx2, gdouble wy2);
 gint world_window_set_center(gdouble mag, gdouble mag_x, gdouble mag_y, gdouble view_x);
 
 void Draw(GtkWidget *widget);
-int ToDeviceX(double x);
-int ToDeviceY(double y);
-double ToViewX(int x);
-double ToViewY(int y);
+int ToViewPortX(double x);
+int ToViewPortY(double y);
+double ToWorldX(int x);
+double ToWorldY(int y);
 
 GdkGC *create_gc(GtkWidget *w);
 void delete_gc(GdkGC *gc);
@@ -112,11 +113,8 @@ int CircleK(GtkWidget *widget, double CX, double CY, double R, double SA, double
 int LineK(GtkWidget *widget, double SX, double SY, double EX, double EY, int style, long color);
 /* 楕円の表示 */
 int EllipseK(GtkWidget *widget, ELLIPSE ellipse, int style, long color);
-//int EllipseK(GtkWidget *widget, 
-//			 double cx, double cy, double a, double b, 
-//			 double sa, double ea, double angle , 
-//			 int style, long color);
 int WakuWakuDraw(GtkWidget *widget);
+double one_pix(void);
 
 
 
