@@ -2856,15 +2856,16 @@ int CreateCircle(GtkWidget *widget)
 				)
 		{
 			/* ２円が同一   c_c   同心円 */
-			if (sg(sel_1->diagram_point.cad_point->cx, 6) 
-					== sg(sel_2->diagram_point.cad_point->cx, 6)
+			if (
+				isEqual(sel_1->diagram_point.cad_point->cx, 
+						sel_2->diagram_point.cad_point->cx, compa_digits) 
 				&& 
-				sg(sel_1->diagram_point.cad_point->cy, 6) 
-					== sg(sel_2->diagram_point.cad_point->cy, 6)
-				)
+				isEqual(sel_1->diagram_point.cad_point->cy, 
+						sel_2->diagram_point.cad_point->cy, compa_digits) 
+				) 
 			{
-				if (sg(sel_1->diagram_point.cad_point->r, 6) 
-						== sg(sel_2->diagram_point.cad_point->r, 6)) 
+				if (isEqual(sel_1->diagram_point.cad_point->r, 
+						sel_2->diagram_point.cad_point->r, compa_digits)) 
 				{
 					c_c();
 					return 1;
