@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2006 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2006 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/05/25
- *    Last                 : 2006/05/25
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 #ifndef __OUTSIDEPROCESS_H__
@@ -26,7 +26,7 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 1 :   (struct #define etc)
+ * 1 : 前処理  (struct #define etc)
  * -------------------------------------------------------
  */
 
@@ -57,11 +57,11 @@ struct _PRE_WORK {
 	 * work :
 	 * 
 	 *      : 0 : None
-	 *      : 1 : MSGBAR : ơСˡå
-	 *      : 2 : MSGBOX : åɽ
-	 *      : 4 : INPUT : ܡɤ
-	 *      : 8 : SELECT,ONE : ޷򣱸
-	 *      : 16 : SELECT,MANY : ޷򤿤
+	 *      : 1 : MSGBAR : ステータスバーに、メッセージ
+	 *      : 2 : MSGBOX : メッセージダイアログ表示
+	 *      : 4 : INPUT : キーボードからの入力
+	 *      : 8 : SELECT,ONE : 図形を１個選択
+	 *      : 16 : SELECT,MANY : 図形をたくさん選択
 	 * 
 	 *      : 32 : OUT_FILE : 
 	 *      : 64 : INP_FILE : 
@@ -71,15 +71,15 @@ struct _PRE_WORK {
 	int		work;
 
 	/* ---------------------------------
-	 * ޷
-	 *		 1 : 
-	 *		 2 : 
-	 *		 4 : ߸
-	 *		 8 : 
-	 *	   128 : Ǥ
-	 *	   256 : ˡ޷
-	 *	   512 : ݥ饤
-	 *	  2048 : ʱ
+	 * 図形要素
+	 *		 1 : 点
+	 *		 2 : 線
+	 *		 4 : 円弧
+	 *		 8 : 円
+	 *	   128 : 任意点
+	 *	   256 : 寸法図形
+	 *	   512 : ポリライン
+	 *	  2048 : 楕円
 	 */
 	int 	sel_obj;
 	
@@ -118,16 +118,16 @@ typedef struct _OUTSIDE_PROCESS OUTSIDE_PROCESS;
 
 
 /* -------------------------------------------------------
- * 2 : ѿ (global)
+ * 2 : 外部変数 (global)
  * -------------------------------------------------------
  */
 #ifdef _OUTSIDEPROCESS_
 #define   GLOBAL
-/*  */
+/* 初期値設定 */
 #define   GLOBAL_VAL(v)  = (v)
 #else
 #define   GLOBAL	extern
-/* ʬ̵ */
+/* 初期値設定の代入部分を無くす */
 #define   GLOBAL_VAL(v)  /* */
 #endif
 
@@ -143,7 +143,7 @@ typedef struct _OUTSIDE_PROCESS OUTSIDE_PROCESS;
 
 
 /* -------------------------------------------------------
- * 3 : ؿ (Function)
+ * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
 
@@ -172,7 +172,7 @@ int ops_PolyLine_read(char *str, FILE *stream);
 #endif /* __cplusplus */
 #endif /* __OUTSIDEPROCESS_H__ */
 /* ====================================================================
- * ===  Copyright (C) 1998-2006 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : OutsideProcess.h
