@@ -357,6 +357,7 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				printset_dlg->up_scale_entry = gtk_entry_new();
 //				gtk_widget_set_size_request(printset_dlg->up_scale_entry, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(scale_hbox), printset_dlg->up_scale_entry, TRUE, TRUE, 1);
+				gtk_entry_set_max_length(GTK_ENTRY(printset_dlg->up_scale_entry), 256);
 				/* 初期値設定 */
 				FloatOut_n(str, printset_dlg->up_scale, 6, 0);
 				gtk_entry_set_text(GTK_ENTRY(printset_dlg->up_scale_entry), str);
@@ -372,6 +373,7 @@ gint PrintSetDialog(PRINTSET_DLG *printset_dlg)
 				printset_dlg->low_scale_entry = gtk_entry_new();
 //				gtk_widget_set_size_request(printset_dlg->low_scale_entry, 80, 20);
 				gtk_box_pack_start((GtkBox *)GTK_BOX(scale_hbox), printset_dlg->low_scale_entry, TRUE, TRUE, 1);
+				gtk_entry_set_max_length(GTK_ENTRY(printset_dlg->low_scale_entry), 256);
 				/* 初期値設定 */
 				FloatOut_n(str, printset_dlg->low_scale, 6, 0);
 				gtk_entry_set_text(GTK_ENTRY(printset_dlg->low_scale_entry), str);
