@@ -13,7 +13,7 @@
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/02/20
- *    Last                 : 2007/10/11
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 #ifndef __SCALINGDLG_H__
@@ -26,16 +26,16 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 1 :   (struct #define etc)
+ * 1 : 前処理  (struct #define etc)
  * -------------------------------------------------------
  */
 
 struct _SCALING_DLG
 {
 	gint value;
-	gdouble x_pos;			/*  */
-	gdouble y_pos;			/*  */
-	gdouble coefficient;	/*  */
+	gdouble x_pos;			/* 原点　Ｘ */
+	gdouble y_pos;			/* 原点　Ｙ */
+	gdouble coefficient;	/* 係数 */
 
 	GtkWidget *x_pos_entry;
 	GtkWidget *y_pos_entry;
@@ -48,16 +48,16 @@ typedef struct _SCALING_DLG SCALING_DLG;
 
 
 /* -------------------------------------------------------
- * 2 : ѿ (global)
+ * 2 : 外部変数 (global)
  * -------------------------------------------------------
  */
 #ifdef _SCALINGDLG_
 #define   GLOBAL
-/*  */
+/* 初期値設定 */
 #define   GLOBAL_VAL(v)  = (v)
 #else
 #define   GLOBAL	extern
-/* ʬ̵ */
+/* 初期値設定の代入部分を無くす */
 #define   GLOBAL_VAL(v)  /* */
 #endif
 
@@ -71,7 +71,7 @@ typedef struct _SCALING_DLG SCALING_DLG;
 
 
 /* -------------------------------------------------------
- * 3 : ؿ (Function)
+ * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
 gint ScalingDialog(SCALING_DLG *scaling_dlg);
