@@ -591,7 +591,8 @@ int TrimL_Run(struct TrimDat *a, double x, double y)
 	ClickA = LAH.angle;
 
 	/* 線の角度とスタート点から交点までの角度が同じ時 */
-	if (sg(SenA, compa_digits-2) == sg(ClickA, compa_digits-2)) {
+//	if (sg(SenA, compa_digits-2) == sg(ClickA, compa_digits-2)) {
+	if (isEqual(SenA, ClickA, compa_digits-2)) {
 		/* スタート点から交点 */
 		if (L < CL) {
 			a->TraceData[1].ex = sg(x, calcu_digits);
@@ -735,8 +736,11 @@ int TrimA_Pull(struct TrimDat *a, double x, double y)
 	 */
 	if (CSL < CEL) {
 		/* 交点と終了点が同じなら円 */
-		if (sg(x, compa_digits) == sg(a->TraceData[1].ex, compa_digits)
-			&& sg(y, compa_digits) == sg(a->TraceData[1].ey, compa_digits))
+		if (
+			isEqual(x, a->TraceData[1].ex, compa_digits)
+			&& 
+			isEqual(y, a->TraceData[1].ey, compa_digits)
+			) 
 		{
 /*
 			Ret = MessageBox(NULL,	(LPCSTR)"交点と終了点が同じです。\n円にしますか？", 
@@ -764,8 +768,11 @@ int TrimA_Pull(struct TrimDat *a, double x, double y)
 	/* クリック点がエンド点に近い。(終了点を修正) */
 	else if (CSL > CEL) {
 		/* 交点と開始点が同じなら円にする。*/
-		if (sg(a->TraceData[1].sx, compa_digits) == sg(x, compa_digits) 
-			&& sg(a->TraceData[1].sy, compa_digits) == sg(y, compa_digits)) 
+		if (
+			isEqual(a->TraceData[1].sx, x, compa_digits)
+			&& 
+			isEqual(a->TraceData[1].sy, y, compa_digits)
+			) 
 		{
 /*
 			Ret = MessageBox(NULL,	(LPCSTR)"交点と開始点が同じです。\n円にしますか？", 
@@ -843,8 +850,11 @@ int TrimA_Run(struct TrimDat *a, double x, double y)
 	/* KA<PA */
 	if (KA < PA) {
 		/* 交点と開始点が同じなら円にする。*/
-		if (sg(a->TraceData[1].sx, compa_digits) == sg(x, compa_digits) 
-			&& sg(a->TraceData[1].sy, compa_digits) == sg(y, compa_digits)) 
+		if (
+			isEqual(a->TraceData[1].sx, x, compa_digits)
+			&& 
+			isEqual(a->TraceData[1].sy, y, compa_digits)
+			) 
 		{
 /*
 			Ret = MessageBox(NULL,	(LPCSTR)"交点と開始点が同じです。\n円にしますか？", 
@@ -870,8 +880,11 @@ int TrimA_Run(struct TrimDat *a, double x, double y)
 	/* KA > PA　：　交点からエンド点 */
 	if (KA > PA) {
 		/* 交点と開始点が同じなら円にする。*/
-		if (sg(a->TraceData[1].ex, compa_digits) == sg(x, compa_digits) 
-			&& sg(a->TraceData[1].ey, compa_digits) == sg(y, compa_digits)) 
+		if (
+			isEqual(a->TraceData[1].ex, x, compa_digits)
+			&& 
+			isEqual(a->TraceData[1].ey, y, compa_digits)
+			) 
 		{
 /*
 			Ret = MessageBox(NULL,	(LPCSTR)"交点と終了点が同じです。\n円にしますか？", 
@@ -1952,7 +1965,7 @@ int TrimEA_Pull(struct TrimDat *a, double x, double y)
 	/* データを修正する前に、前の線を消す */
 	if (CSL < CEL) {
 		/* 交点と終了点が同じなら円 */
-		if (sg(a->ellipse[1].ea, compa_digits) == sg(PA, compa_digits)) {
+		if (isEqual(a->ellipse[1].ea, PA, compa_digits)) {
 /*
 			Ret = MessageBox(NULL,	(LPCSTR)"交点と終了点が同じです。\n円にしますか？", 
 								(LPCSTR)"確認" ,	
@@ -1978,7 +1991,7 @@ int TrimEA_Pull(struct TrimDat *a, double x, double y)
 	/* クリック点がエンド点に近い。(終了点を修正) */
 	else if (CSL > CEL) {
 		/* 交点と開始点が同じなら円にする。*/
-		if (sg(a->ellipse[1].sa, compa_digits) == sg(PA, compa_digits)) {
+		if (isEqual(a->ellipse[1].sa, PA, compa_digits)) {
 /*
 			Ret = MessageBox(NULL,	(LPCSTR)"交点と開始点が同じです。\n円にしますか？", 
 								(LPCSTR)"確認" ,	
@@ -2065,7 +2078,7 @@ int TrimEA_Run(struct TrimDat *a, double x, double y)
 	if (ka < pa) {
 		if (debug > 0) g_print("TrimEA_Run() : KA < PA : 交点から開始点\n");
 		/* 交点と開始点が同じなら円にする。*/
-		if (sg(SA, compa_digits) == sg(PA, compa_digits)) {
+		if (isEqual(SA, PA, compa_digits)) {
 			return 0;
 		}
 		else {
@@ -2079,7 +2092,7 @@ int TrimEA_Run(struct TrimDat *a, double x, double y)
 	if (ka > pa) {
 		if (debug > 0) g_print("TrimEA_Run() : KA > PA ： 交点から終了点\n");
 		/* 交点と終了点が同じなら円にする。*/
-		if (sg(a->ellipse[1].ea, compa_digits) == sg(PA, compa_digits)) { 
+		if (isEqual(a->ellipse[1].ea, PA, compa_digits)) {
 			if (debug > 0) g_print("TrimEA_Run() : 交点と終了点が同じ\n");
 			return 0;
 		}
@@ -2306,9 +2319,9 @@ int Split(struct TrimDat *a)
 		 * チェック
 		 */
 		if (
-				sg(PointX, compa_digits) == sg(a->TraceData[1].sx, compa_digits) 
-				&& 
-				sg(PointY, compa_digits) == sg(a->TraceData[1].sy, compa_digits)
+			isEqual(PointX, a->TraceData[1].sx, compa_digits)
+			&& 
+			isEqual(PointY, a->TraceData[1].sy, compa_digits)
 			) 
 		{
 			strcpy(str, "Split : error : ");
@@ -2318,10 +2331,10 @@ int Split(struct TrimDat *a)
 			return 0;
 		}
 		else if (
-					sg(PointX, compa_digits) == sg(a->TraceData[1].ex, compa_digits) 
-					&& 
-					sg(PointY, compa_digits) == sg(a->TraceData[1].ey, compa_digits)
-				) 
+			isEqual(PointX, a->TraceData[1].ex, compa_digits)
+			&& 
+			isEqual(PointY, a->TraceData[1].ey, compa_digits)
+			) 
 		{
 			strcpy(str, "Split : error : ");
 			strcat(str, _("The division point is the same as the end point."));
@@ -2402,9 +2415,9 @@ int Split(struct TrimDat *a)
 		 * チェック
 		 */
 		if (
-				sg(PointX, compa_digits) == sg(a->TraceData[1].sx, compa_digits) 
-				&& 
-				sg(PointY, compa_digits) == sg(a->TraceData[1].sy, compa_digits)
+			isEqual(PointX, a->TraceData[1].sx, compa_digits)
+			&& 
+			isEqual(PointY, a->TraceData[1].sy, compa_digits)
 			)
 		{
 			strcpy(str, "Split : error : ");
@@ -2415,10 +2428,10 @@ int Split(struct TrimDat *a)
 		}
 
 		else if (
-					sg(PointX, compa_digits) == sg(a->TraceData[1].ex, compa_digits) 
-					&& 
-					sg(PointY, compa_digits) == sg(a->TraceData[1].ey, compa_digits)
-				)
+			isEqual(PointX, a->TraceData[1].ex, compa_digits)
+			&& 
+			isEqual(PointY, a->TraceData[1].ey, compa_digits)
+			)
 		{
 			strcpy(str, "Split : error : ");
 			strcat(str, _("The division point is the same as the end point."));
@@ -2522,17 +2535,9 @@ int Split(struct TrimDat *a)
 		/* 分割点が始点と同じ */
 		get_ellipse_point_from_angle (a->ellipse[1], a->ellipse[1].sa, &point);
 		if (
-				(
-					PointX + (1/pow(10, compa_digits)) > point.x
-					&&
-					PointX - (1/pow(10, compa_digits)) < point.x
-				)
-				&& 
-				(
-					PointY + (1/pow(10, compa_digits)) > point.y
-					&&
-					PointY - (1/pow(10, compa_digits)) < point.y
-				)
+			isEqual(PointX, point.x, compa_digits)
+			&& 
+			isEqual(PointY, point.y, compa_digits)
 			)
 		{
 			sprintf(str, "Split() : error : ");
@@ -2545,17 +2550,9 @@ int Split(struct TrimDat *a)
 		/* 分割点が終点と同じ */
 		get_ellipse_point_from_angle (a->ellipse[1], a->ellipse[1].ea, &point);
 		if (
-				(
-					PointX + (1/pow(10, compa_digits)) > point.x
-					&&
-					PointX - (1/pow(10, compa_digits)) < point.x
-				)
-				&& 
-				(
-					PointY + (1/pow(10, compa_digits)) > point.y
-					&&
-					PointY - (1/pow(10, compa_digits)) < point.y
-				)
+			isEqual(PointX, point.x, compa_digits)
+			&& 
+			isEqual(PointY, point.y, compa_digits)
 			)
 		{
 			sprintf(str, "Split() : error : ");
