@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2006 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2006 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2001/02/27
- *    Last                 : 2006/05/25
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 
@@ -29,17 +29,17 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 1 :   (struct #define etc)
+ * 1 : 前処理  (struct #define etc)
  * -------------------------------------------------------
  */
-	// ȥѿ
+	// トリム変数
 	struct TrimDat
 	{
-		int Index;		// 1:ȥ    2:ξȥ
-		CAD TraceData[4];	// ޷ǡ(1-3) ʱߤλ code = 2048
+		int Index;		// 1:片方トリム    2:両方トリム
+		CAD TraceData[4];	// 図形データ(1-3) 楕円の時は code = 2048
 		ELLIPSE ellipse[4];
-		double PicX[4];		// ԥå(1-3)
-		double PicY[4];		// ԥå(1-3)
+		double PicX[4];		// ピック点Ｘ(1-3)
+		double PicY[4];		// ピック点Ｙ(1-3)
 		double pointX1;
 		double pointY1;
 		double pointX2;
@@ -49,16 +49,16 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 2 : ѿ (global)
+ * 2 : 外部変数 (global)
  * -------------------------------------------------------
  */
 #ifdef	  _TRIMFUNC_
 #define   GLOBAL
-// 
+// 初期値設定
 #define   GLOBAL_VAL(v)  = (v)
 #else
 #define   GLOBAL	extern
-// ʬ̵
+// 初期値設定の代入部分を無くす
 #define   GLOBAL_VAL(v)  /* */
 #endif
 
@@ -72,7 +72,7 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 3 : ؿ (Function)
+ * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
 int TrimMain(struct TrimDat *a);
@@ -118,7 +118,7 @@ double Arc_SE_Angle(CAD Data, int Frag);
 #endif /* __cplusplus */
 #endif /* __TRIMFUNC_H__ */
 /* ====================================================================
- * ===  Copyright (C) 1998-2006 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Source               : TrimFunc.h
