@@ -81,6 +81,7 @@ extern "C" {
  * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
+int isEqual(double a, double b, int isEqual_digits);
 int arc_max_and_min(struct RtnDat *rtn);
 
 double raddeg(double a);					/*	1 */
@@ -115,10 +116,10 @@ int ChkPointLineSide(struct RtnDat *a);
 int LCP1(struct RtnDat *a);
 int CCP1(struct RtnDat *a);
 
-gint near_point_on_line(gdouble *x, gdouble *y, gdouble sx, gdouble sy, gdouble ex, gdouble ey);
-gint near_point_on_circle(gdouble *x, gdouble *y, gdouble cx, gdouble cy, gdouble r);
-gint point_on_line(gdouble x, gdouble y, gdouble sx, gdouble sy, gdouble ex, gdouble ey);
-gint point_on_arc(gdouble x, gdouble y, gdouble cx, gdouble cy, gdouble r, gdouble sx, gdouble sy, gdouble ex, gdouble ey);
+int near_point_on_line(double *x, double *y, double sx, double sy, double ex, double ey);
+int near_point_on_circle(double *x, double *y, double cx, double cy, double r);
+int point_on_line(double x, double y, double sx, double sy, double ex, double ey);
+int point_on_arc(double x, double y, double cx, double cy, double r, double sx, double sy, double ex, double ey);
 int Act_llp(struct RtnDat *a);
 int Act_lcp(struct RtnDat *a);
 int Act_ccp(struct RtnDat *dumy);
