@@ -13,7 +13,7 @@
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2002/09/11
- *    Last                 : 2007/10/10
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 
@@ -77,8 +77,8 @@ int sagcad_global_init(void)
 	strcpy(sagcad_user.KeepCadPath, home);
 	strcpy(sagcad_user.NcPath, "CADPATH");
 
-	strcpy(sagcad_user.browser_command, "netscape %s");
-	strcpy(sagcad_user.editor_command, "kterm -e vi %s");
+	strcpy(sagcad_user.browser_command, "mozilla %s");
+	strcpy(sagcad_user.editor_command, "gvim %s");
 	strcpy(sagcad_user.print_command, "lpr %s");
 
 
@@ -1235,7 +1235,7 @@ int ConfigWrite(void)
 	fputs(str, stream);
 	sprintf(str, "#    Begin                : 2001/03/27\n");
 	fputs(str, stream);
-	sprintf(str, "#    Last                 : 2002/10/12\n");
+	sprintf(str, "#    Last                 : 2007/11/08\n");
 	fputs(str, stream);
 	sprintf(str, "# ====================================================================\n");
 	fputs(str, stream);
