@@ -197,14 +197,6 @@ static void destroy(GtkWidget *widget, gpointer data)
  */
 int main(int argc, char *argv[])
 {
-//#define TEST_HANDLE_BOX
-
-#ifdef TEST_HANDLE_BOX
-	GtkWidget *handle_toolbar;
-	GtkWidget *handle_textbar;
-	GtkWidget *handle_statusbar;
-#endif
-
 	char str[64], str2[64], msg[256];
 	GtkWidget *vbox;
 	GtkWidget *toolbar;
@@ -338,21 +330,12 @@ int main(int argc, char *argv[])
 	gtk_box_pack_start(GTK_BOX(vbox), separator, FALSE, FALSE, 0);
 	gtk_widget_show(separator);
 
-
-
-
-
-
 	/* text_hbox 生成 (横に追加) */
 	text_hbox = gtk_hbox_new(FALSE, 2);
 	gtk_container_set_border_width(GTK_CONTAINER(text_hbox), 2);
 	gtk_box_pack_start(GTK_BOX(vbox), text_hbox, FALSE, FALSE, 0);
 	gtk_widget_show(text_hbox);
 
-
-
-
-
 	/* 線ステータスバーの生成 */
 	line_status = create_line_style_box();
 	gtk_box_pack_start(GTK_BOX(text_hbox), line_status, FALSE, FALSE, 0);
@@ -463,33 +446,41 @@ int main(int argc, char *argv[])
 	drawing_area = create_drawing_area();
 	gtk_box_pack_start(GTK_BOX(work_hbox), drawing_area, TRUE, TRUE, 0);
 	gtk_widget_show(drawing_area);
-	/* -------------------------------------------------------------------------------
-	   マウスカーソル作成 
-	   GDK_CROSS  GDK_IRON_CROSS  [GDK_CROSSHAIR]  GDK_DIAMOND_CROSS  [GDK_TCROSS]
-	 */
-//	cursor = gdk_cursor_new(GDK_TCROSS);
-//	gdk_window_set_cursor(drawing_area->window, cursor);
 
 
 
+GtkWidget *status_area;
+GtkWidget *statusbar_grip;
 
-
-#ifdef TEST_HANDLE_BOX
-	handle_statusbar = gtk_handle_box_new();
-	gtk_box_pack_start(GTK_BOX(vbox), handle_statusbar, FALSE, FALSE, 0);
-	gtk_widget_show(handle_statusbar);
-#endif
-
+	status_area = gtk_hbox_new(FALSE, 2);
+	gtk_box_pack_start(GTK_BOX(vbox), status_area, FALSE, FALSE, 0);
+	gtk_widget_show(status_area);
+	
+	
+	
 	/* ステータスバーの生成 */
 	statusbar = gtk_entry_new();
-#ifdef TEST_HANDLE_BOX
-	gtk_container_add(GTK_CONTAINER(handle_statusbar), statusbar);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), statusbar, FALSE, FALSE, 0);
+	//gtk_widget_set_size_request(statusbar_grip, 10, TEXT_H_BOX_HEIGHT);
+	gtk_box_pack_start(GTK_BOX(status_area), statusbar, TRUE, TRUE, 0);
 	gtk_editable_set_editable(GTK_EDITABLE(statusbar), FALSE);
-#endif
+	gtk_entry_set_max_length(GTK_ENTRY(statusbar), 256);
 	gtk_widget_show(statusbar);
 
+	statusbar_grip = gtk_statusbar_new();
+	gtk_widget_set_size_request(statusbar_grip, 20, TEXT_H_BOX_HEIGHT);
+	gtk_box_pack_end(GTK_BOX(status_area), statusbar_grip, FALSE, FALSE, 0);
+	gtk_widget_show(statusbar_grip);
+
+
+
+
+	/* ステータスバーの生成 */
+/*	statusbar = gtk_entry_new();
+	gtk_box_pack_start(GTK_BOX(vbox), statusbar, FALSE, FALSE, 0);
+	gtk_editable_set_editable(GTK_EDITABLE(statusbar), FALSE);
+	gtk_entry_set_max_length(GTK_ENTRY(statusbar), 256);
+	gtk_widget_show(statusbar);
+*/
 
 
 
@@ -725,6 +716,14 @@ int StatusMsg(char *str)
 	gtk_entry_set_text(GTK_ENTRY(statusbar), str);
 	UpDate_widget(statusbar);
 	return 1;
+
+	gint context_id, message_id;
+	
+	context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(statusbar), str);
+	message_id = gtk_statusbar_push(GTK_STATUSBAR(statusbar), context_id, str);
+	//gtk_statusbar_pop(GTK_STATUSBAR(statusbar), context_id);
+	//gtk_statusbar_remove(statusbar, context_id, message_id);
+	return 0;
 }
 
 int StatusMsg_MouseX(char *str)
