@@ -2136,8 +2136,8 @@ int WriteClipFile(void)
 	char Path[256], str[256];
 	FILE *stream;
 	SELECT_LIST *sp;
-
-
+	int org_data_version;
+	
 	/* -----------------------------------------------------
 	 * Open File
 	 */
@@ -2148,12 +2148,15 @@ int WriteClipFile(void)
 		MsgBox("SagCAD ERROR", str, " ", NULL, NULL, "OK");
 		return 0;
 	}
-
-
+	
+	org_data_version = data_version;
+	data_version = CHARSET_UTF8;
+	
 	/* -----------------------------------------------------
 	 * TRACE SECTION
 	 */
-	sprintf(str, "TRACE (Layer, Code, Style, Color, SX, SY, EX, EY, CX, CY, R, 予備)\n");
+	sprintf(str, 
+			"TRACE (Layer, Code, Style, Color, SX, SY, EX, EY, CX, CY, R, stok)\n");
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
 	/* 各図形要素 */
 	sp = select_list_info.head;
@@ -2163,7 +2166,14 @@ int WriteClipFile(void)
 	 */
 	while (sp != NULL) {
 		if (sp->select->index == 2 || sp->select->index == 4) {
-			if (trace_data_write(stream, cad_search_cad(sp->select->diagram_point.cad_point, &cad_list_info)) == 0) {
+			if (trace_data_write(
+					stream, 
+					cad_search_cad(
+						sp->select->diagram_point.cad_point, 
+						&cad_list_info
+					)
+				) == 0) 
+			{
 				fclose(stream);
 				return 0;
 			}
@@ -2175,9 +2185,8 @@ int WriteClipFile(void)
 	}
 	sprintf(str, "TRACE END\n");
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
-
-
+	
+	
 	/* -----------------------------------------------------
 	 * DIMENSION SECTION
 	 */
@@ -2203,9 +2212,8 @@ int WriteClipFile(void)
 	}
 	sprintf(str, "DIMENSION END\n");
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
-
-
+	
+	
 	/* -----------------------------------------------------
 	 * POLYLINE SECTION
 	 */
@@ -2219,9 +2227,13 @@ int WriteClipFile(void)
 	 */
 	while (sp != NULL) {
 		if (sp->select->index == 8) {
-			if (PolyLine_data_write(stream, 
-									polyline_search_polyline(sp->select->diagram_point.polyline_point, 
-															 &polyline_list_info)) == 0) 
+			if (PolyLine_data_write(
+					stream, 
+					polyline_search_polyline(
+						sp->select->diagram_point.polyline_point, 
+						&polyline_list_info
+					)
+				) == 0) 
 			{
 				fclose(stream);
 				return 0;
@@ -2231,9 +2243,8 @@ int WriteClipFile(void)
 	}
 	sprintf(str, "POLYLINE END\n");
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
-
-
+	
+	
 	/* -----------------------------------------------------
 	 * ELLIPSE SECTION
 	 */
@@ -2247,9 +2258,13 @@ int WriteClipFile(void)
 	 */
 	while (sp != NULL) {
 		if (sp->select->index == 16) {
-			if (ellipse_data_write(stream, 
-								   ellipse_search_ellipse(sp->select->diagram_point.ellipse_point, 
-														  &ellipse_list_info)) == 0) 
+			if (ellipse_data_write(
+					stream, 
+					ellipse_search_ellipse(
+						sp->select->diagram_point.ellipse_point, 
+						&ellipse_list_info
+					)
+				) == 0) 
 			{
 				fclose(stream);
 				return 0;
@@ -2259,27 +2274,25 @@ int WriteClipFile(void)
 	}
 	sprintf(str, "ELLIPSE END\n");
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
-
-
+	
+	
 	/* -----------------------------------------------------
 	 * INSERT SECTION
 	 */
-
-
-
+	
+	
 	/* -----------------------------------------------------
 	 * EOF SECTION
 	 */
 	sprintf(str, "EOF\n");
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
-
-
+	
+	
 	/* -----------------------------------------------------
 	 * Close File
 	 */
 	fclose(stream);
+	data_version = org_data_version;
 	return 1;
 }
 
@@ -2302,8 +2315,7 @@ int ReadClipFile(void)
 	ELLIPSE ellipse;
 	POLYLINE polyline;
 	char Path[256], str[256];
-
-
+	
 	/* -----------------------------------------------------
 	 * Open File
 	 */
@@ -2314,14 +2326,13 @@ int ReadClipFile(void)
 		MsgBox("SagCAD ERROR", str, " ", NULL, NULL, "OK");
 		return 0;
 	}
-
-
+	
 	while(1){
 		if (read_utf8_from_locale(stream, str, CHARSET_UTF8) == 0) {
 			fclose(stream);
 			return 0;
 		}
-
+		
 		/* -----------------------------------------------------
 		 * TRACE SECTION
 		 */
@@ -2331,17 +2342,19 @@ int ReadClipFile(void)
 					fclose(stream);
 					return 0;
 				}
-
+				
 				if (strstr (str, "TRACE END") != NULL ) break;
-
+				
 				else {
-					if (TraceLook(str, &cad, 4) == 0) {
-						MsgBox("SagCAD ERROR", "Clip File Read Error.  (Trace Data)", " ", NULL, NULL, "OK");
+					if (TraceLook(str, &cad, CHARSET_UTF8) == 0) {
+						MsgBox("SagCAD ERROR", 
+								"Clip File Read Error.  (Trace Data)", 
+								" ", NULL, NULL, "OK");
 						fclose(stream);
 						return 0;
 					}
 					cad.layer = NowLayer;
-
+					
 					if (Undo_frag == 0) {
 						Undo_frag = 1;
 						undo_index_plus();
@@ -2351,32 +2364,33 @@ int ReadClipFile(void)
 				}
 			}
 		}
-
-
-
+		
 		/* -----------------------------------------------------
 		 * DIMENSION SECTION
 		 */
 		else if(strstr(str, "DIMENSION") != NULL) {
 			/* Undo_index をインクリメントする */
 			undo_index_plus();
-
+			
 			while(1) {
 				if (read_utf8_from_locale(stream, str, CHARSET_UTF8) == 0) {
 					fclose(stream);
 					return 0;
 				}
-
-				if(strstr(str, "DEMENSION END") != NULL || strstr(str, "DIMENSION END") != NULL) break;
-
+				
+				if(strstr(str, "DEMENSION END") != NULL 
+						|| strstr(str, "DIMENSION END") != NULL) break;
+				
 				else {
-					if (DimensionLook(str, &dimension, stream, 4) == 0) {
-						MsgBox("SagCAD ERROR", "Clip File Read Error.  (Dimension Data)", " ", NULL, NULL, "OK");
+					if (DimensionLook(str, &dimension, stream, CHARSET_UTF8) == 0) {
+						MsgBox("SagCAD ERROR", 
+								"Clip File Read Error.  (Dimension Data)", 
+								" ", NULL, NULL, "OK");
 						fclose(stream);
 						return 0;
 					}
 					dimension.Layer = NowLayer;
-
+					
 					if (Undo_frag == 0) {
 						Undo_frag = 1;
 						undo_index_plus();
@@ -2386,9 +2400,7 @@ int ReadClipFile(void)
 				}
 			}
 		}
-
-
-
+		
 		/* -----------------------------------------------------
 		 * POLYLINE SECTION
 		 */
@@ -2398,17 +2410,19 @@ int ReadClipFile(void)
 					fclose(stream);
 					return 0;
 				}
-
+				
 				if (strstr (str, "POLYLINE END") != NULL ) break;
-
+				
 				else {
-					if (PolyLineLook(str, &polyline, stream, 4) == 0) {
-						MsgBox("SagCAD ERROR", "Clip File Read Error.  (PolyLine Data)", " ", NULL, NULL, "OK");
+					if (PolyLineLook(str, &polyline, stream, CHARSET_UTF8) == 0) {
+						MsgBox("SagCAD ERROR", 
+								"Clip File Read Error.  (PolyLine Data)", 
+								" ", NULL, NULL, "OK");
 						fclose(stream);
 						return 0;
 					}
 					polyline.layer = NowLayer;
-
+					
 					if (Undo_frag == 0) {
 						Undo_frag = 1;
 						undo_index_plus();
@@ -2418,9 +2432,7 @@ int ReadClipFile(void)
 				}
 			}
 		}
-
-
-
+		
 		/* -----------------------------------------------------
 		 * ELLIPSE SECTION
 		 */
@@ -2430,17 +2442,19 @@ int ReadClipFile(void)
 					fclose(stream);
 					return 0;
 				}
-
+				
 				if (strstr (str, "ELLIPSE END") != NULL ) break;
-
+				
 				else {
-					if (EllipseLook(str, &ellipse, 4) == 0) {
-						MsgBox("SagCAD ERROR", "Clip File Read Error.  (Ellipse Data)", " ", NULL, NULL, "OK");
+					if (EllipseLook(str, &ellipse, CHARSET_UTF8) == 0) {
+						MsgBox("SagCAD ERROR", 
+								"Clip File Read Error.  (Ellipse Data)", 
+								" ", NULL, NULL, "OK");
 						fclose(stream);
 						return 0;
 					}
 					ellipse.layer = NowLayer;
-
+					
 					if (Undo_frag == 0) {
 						Undo_frag = 1;
 						undo_index_plus();
@@ -2450,20 +2464,18 @@ int ReadClipFile(void)
 				}
 			}
 		}
-
-
-
+		
 		/* -----------------------------------------------------
 		 * INSERT SECTION
 		 */
-
-
-
+		
+		
+		
 		/* -----------------------------------------------------
 		 * EOF SECTION
 		 */
 		else if(strstr(str,"EOF") != NULL ) break;
-
+		
 	}
 	fclose(stream);
 	return 1;
@@ -2547,7 +2559,9 @@ int ReadPartsFileNameGet(char *OpenFileName, double x, double y)
 
 				else {
 					if (TraceLook(str, &cad, Version) == 0) {
-						MsgBox("ERROR", "File Read Error.  (Trace Data)", " ", NULL, NULL, "OK");
+						MsgBox("ERROR", 
+								"File Read Error.  (Trace Data)", 
+								" ", NULL, NULL, "OK");
 						fclose(stream);
 						return 0;
 					}
@@ -2580,16 +2594,19 @@ int ReadPartsFileNameGet(char *OpenFileName, double x, double y)
 					fclose(stream);
 					return 0;
 				}
-
-				if(strstr(str, "DEMENSION END") != NULL || strstr(str, "DIMENSION END") != NULL) break;
-
+				
+				if(strstr(str, "DEMENSION END") != NULL 
+						|| strstr(str, "DIMENSION END") != NULL) break;
+				
 				else {
 					if (DimensionLook(str, &dimension, stream, Version) == 0) {
-						MsgBox("ERROR", "File Read Error.  (Dimension Data)", " ", NULL, NULL, "OK");
+						MsgBox("ERROR", 
+								"File Read Error.  (Dimension Data)", 
+								" ", NULL, NULL, "OK");
 						fclose(stream);
 						return 0;
 					}
-
+					
 					dimension.Layer = NowLayer;
 					dimension.SearchPointX = dimension.SearchPointX + x;
 					dimension.SearchPointY = dimension.SearchPointY + y;
@@ -2619,7 +2636,7 @@ int ReadPartsFileNameGet(char *OpenFileName, double x, double y)
 		 * EOF SECTION
 		 */
 		else if(strstr(str,"EOF") != NULL ) break;
-
+		
 	}
 	fclose(stream);
 	return 1;
@@ -2641,44 +2658,44 @@ int MakeFont(void)
 	char CX[256], CY[256], R[256];
 	double sx, sy, ex, ey, cx, cy, r;
 	int i;
-
-
+	
+	
 	str[0] = '\0';
 	InputBox_s(hMainWnd, "文字 ?", str, moji);
 	if (moji[0] == 'C' )	return 0;
-
-
+	
+	
 	sprintf(str, "%s%s.sft", sagcad_user.CadPath, moji);
 	if((stream = fopen( str, "w")) == NULL) {
 		sprintf(mstr,  _("The file could not be opened. [%s]\n") , str);
 		MessageBox(NULL, mstr, (LPCSTR)"動作確認", MB_OK);
 		return 0;
 	}
-
-
+	
+	
 	sprintf(str, "s_%s\n", moji);
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
-
+	
+	
 	FloatOut(str, 100, 0);
 	InputBox_s(hMainWnd, "width ?", str, moji);
 	if (moji[0] == 'C' )	return 0;
 	sprintf(str, "%s\n", moji);
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
+	
 	FloatOut(str, 100, 0);
 	InputBox_s(hMainWnd, "height ?", str, moji);
 	if (moji[0] == 'C' )	return 0;
 	sprintf(str, "%s\n", moji);
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
-
+	
+	
 	sprintf(str, "%d\n", SelectData-1);
 	write_locale_from_utf8(str, stream, CHARSET_UTF8);
-
-
+	
+	
 	if(cad[Select[SelectData].Data].Code != 0) return 0;
-
+	
 	for (i = 1 ; i < SelectData ; i++) {
 		sx = cad[Select[i].Data].SX - cad[Select[SelectData].Data].SX;
 		sy = cad[Select[i].Data].SY - cad[Select[SelectData].Data].SY;
@@ -2687,7 +2704,7 @@ int MakeFont(void)
 		cx = cad[Select[i].Data].CX - cad[Select[SelectData].Data].SX;
 		cy = cad[Select[i].Data].CY - cad[Select[SelectData].Data].SY;
 		 r = cad[Select[i].Data].R;
-
+		
 		if (cad[Select[i].Data].Code == 0) {
 			ex = 0;
 			ey = 0;
@@ -2706,7 +2723,7 @@ int MakeFont(void)
 			ex = 0;
 			ey = 0;
 		}
-
+		
 		FloatOut6(SX, sx, 0);
 		FloatOut6(SY, sy, 0);
 		FloatOut6(EX, ex, 0);
@@ -2714,13 +2731,13 @@ int MakeFont(void)
 		FloatOut6(CX, cx, 0);
 		FloatOut6(CY, cy, 0);
 		FloatOut6( R,  r, 0);
-
+		
 		sprintf(str, "%d,%s,%s,%s,%s,%s,%s,%s\n",
 					cad[Select[i].Data].Code,
 					SX, SY, EX, EY, CX, CY, R);
 		write_locale_from_utf8(str, stream, CHARSET_UTF8);
 	}
-
+	
 	fclose(stream);
 	return 1;
 }
