@@ -35,7 +35,7 @@ GtkWidget *create_hbox_toolbar(GtkWidget *container)
 		{_("Open"),						GTK_STOCK_OPEN,			NULL,			cmd_open,				1, 0},
 		{_("Save As"),					GTK_STOCK_SAVE_AS,		NULL,			cmd_rename,				1, 0},
 		{_("Save"),						GTK_STOCK_SAVE,			NULL,			cmd_save,				1, 0},
-		{_("Part Insert"),				NULL,					Parts_in_xpm,	cmd_parts_in,			0, 0},
+		{_("Part Insert"),				GTK_STOCK_EXECUTE,	NULL/*Parts_in_xpm*/,	cmd_parts_in,		1, 0},
 		{_("Print"),					GTK_STOCK_PRINT,		NULL,			cmd_print,				1, 0},
 		{_("Printer Setting"),			NULL,					print_setup_xpm,cmd_print_set,			0, 0},
 		{_("Quit"),						GTK_STOCK_QUIT,			NULL,			cmd_end,				1, 0},
@@ -116,7 +116,7 @@ void AppendButtons(GtkWidget *container, GtkWidget *toolbar, struct ToolBarItem
 		
 		button = gtk_button_new();
 		gtk_button_set_image(GTK_BUTTON(button), image);
-		gtk_widget_set_size_request(button, TLLOBAR_ICON_SIZE, TLLOBAR_ICON_SIZE);
+		gtk_widget_set_size_request(button, TOOLBAR_ICON_SIZE, TOOLBAR_ICON_SIZE);
 		gtk_box_pack_start(GTK_BOX(toolbar), button, FALSE, FALSE, 0);
 		tooltips = gtk_tooltips_new();
 		gtk_tooltips_set_tip(tooltips, button, Item->tooltips, Item->tooltips);
@@ -159,7 +159,7 @@ GtkWidget *create_table_toolbar(GtkWidget *container)
 {
 	/* ツールバーに載せるボタン */
 	struct TableToolBarItem table_toolbar_item[] = {
-		{_("Delete"),					GTK_STOCK_DELETE,	NULL,					cmd_delete,			0,  0, 1},
+//		{_("Delete"),					GTK_STOCK_DELETE,	NULL,					cmd_delete,			0,  0, 1},
 		{_("Drawing"),					NULL,				Draw_xpm,				cmd_draw,			0,  1, 0},
 		{_("Trim"),						NULL,				Trim_xpm,				cmd_trim,			0,  2, 0},
 		{_("Fillet"),					NULL,				Fillet_xpm,				cmd_fillet,			0,  3, 0},
@@ -173,21 +173,21 @@ GtkWidget *create_table_toolbar(GtkWidget *container)
 		{_("Rotate"),					NULL,				Roll_xpm,				cmd_turn,			0,  9, 0},
 		{_("Scaling"),					NULL,				Scaling_xpm,			cmd_scaling,		0, 10, 0},
 		{_("Layer Copy"),				NULL,				LayerCopy_xpm,			cmd_layer_copy,		0, 11, 0},
-		{TABLE_SPACE,					NULL,				NULL,					NULL,				0, 11, 0},
+		{_("Dimension Property"),		NULL,				DimenProperty_xpm,		not_make,			0, 12, 0},
+		{TABLE_SPACE,					NULL,				NULL,					NULL,				0, 12, 0},
 
-		{_("Horizontal Dimension"),		NULL,				DimenX_xpm,				cmd_x_dimension,	0, 12, 0},
-		{_("Distance Dimension"),		NULL,				DimenDistance_xpm,		cmd_p_dimension,	0, 13, 0},
-		{_("Radius Dimansion"),			NULL,				DimenR_xpm,				cmd_r_dimension,	0, 14, 0},
-		{_("Coordinates Dimension"),	NULL,				DimenPoint_xpm,			cmd_pt_dimension,	0, 15, 0},
-		{_("Text"),						NULL,				DimenAtension_xpm,		cmd_at_dimension,	0, 16, 0},
-		{TABLE_SPACE,					NULL,				NULL,					NULL ,				0, 16, 0},
+		{_("Horizontal Dimension"),		NULL,				DimenX_xpm,				cmd_x_dimension,	0, 13, 0},
+		{_("Distance Dimension"),		NULL,				DimenDistance_xpm,		cmd_p_dimension,	0, 14, 0},
+		{_("Radius Dimansion"),			NULL,				DimenR_xpm,				cmd_r_dimension,	0, 15, 0},
+		{_("Coordinates Dimension"),	NULL,				DimenPoint_xpm,			cmd_pt_dimension,	0, 16, 0},
+		{_("Text"),						NULL,				DimenAtension_xpm,		cmd_at_dimension,	0, 17, 0},
+		{TABLE_SPACE,					NULL,				NULL,					NULL ,				0, 17, 0},
 
-		{_("CAM"),						NULL,				CamProfile_xpm,			cmd_profile,		0, 17, 0},
-		{_("Outside Process"),			NULL,				outside_process_xpm,	cmd_outside_process,	0, 18, 0},
+		{_("CAM"),						NULL,				CamProfile_xpm,			cmd_profile,		0, 18, 0},
+//		{_("Outside Process"),			NULL,				outside_process_xpm,	cmd_outside_process,	0, 19, 0},
+		{_("Outside Process"),			GTK_STOCK_CONVERT,	NULL,					cmd_outside_process,	0, 19, 1},
 
-
-
-		{_("Cancel"),					NULL,				Cancel_xpm,				cmd_all_cancel,		1,  0, 0},
+//		{_("Cancel"),					NULL,				Cancel_xpm,				cmd_all_cancel,		1,  0, 0},
 		{_("Divide"),					NULL,				Split_xpm,				cmd_split,			1,  1, 0},
 		{_("Trim two"),					NULL,				Both_Trim_xpm,			cmd_both_trim,		1,  2, 0},
 		{_("Chamfer"),					NULL,				C_Cut_xpm,				cmd_Chamfering,		1,  3, 0},
@@ -199,19 +199,21 @@ GtkWidget *create_table_toolbar(GtkWidget *container)
 		{_("Rect Select"),				NULL,				RectSelect_xpm,			cmd_rect_select,	1,  7, 0},
 		{_("Parallel"),					NULL,				Para_xpm,				cmd_parallel_copy,	1,  8, 0},
 		{_("Procession Copy"),			NULL,				Matrix_xpm,				cmd_grid_copy,		1,  9, 0},
-		{_("Line Style Change"),		NULL,				LineStyleChange_xpm,	cmd_line_style_change,	1, 10, 0},
+//		{_("Line Style Change"),		NULL,				LineStyleChange_xpm,	cmd_line_style_change,	1, 10, 0},
+		{_("Line Style Change"), GTK_STOCK_SELECT_COLOR,	NULL,					cmd_line_style_change,	1, 10, 1},
 		{_("Layer Move"),				NULL,				LayerMove_xpm,			cmd_layer_move,		1, 11, 0},
-		{TABLE_SPACE,					NULL,				NULL,					NULL ,				1, 11, 0},
+		{_("Delete"),					GTK_STOCK_DELETE,	NULL,					cmd_delete,			1, 12, 1},
+		{TABLE_SPACE,					NULL,				NULL,					NULL ,				1, 12, 0},
 
-		{_("Vertical Dimension"),		NULL,				DimenY_xpm,				cmd_y_dimension,	1, 12, 0},
-		{_("Angle Dimension"),			NULL,				DimenAngle_xpm,			cmd_a_dimension,	1, 13, 0},
-		{_("Diameter Dimension"),		NULL,				DimenD_xpm,				cmd_d_dimension,	1, 14, 0},
-		{_("Drawer Line Dimension"),	NULL,				DimenPullLine_xpm,		cmd_hd_dimension,	1, 15, 0},
-		{_("Edit Dimension"),			NULL,				DimenEdit_xpm,			cmd_edt_dimension,	1, 16, 0},
-		{TABLE_SPACE,					NULL,				NULL,					NULL ,				1, 16, 0},
+		{_("Vertical Dimension"),		NULL,				DimenY_xpm,				cmd_y_dimension,	1, 13, 0},
+		{_("Angle Dimension"),			NULL,				DimenAngle_xpm,			cmd_a_dimension,	1, 14, 0},
+		{_("Diameter Dimension"),		NULL,				DimenD_xpm,				cmd_d_dimension,	1, 15, 0},
+		{_("Drawer Line Dimension"),	NULL,				DimenPullLine_xpm,		cmd_hd_dimension,	1, 16, 0},
+		{_("Edit Dimension"),			NULL,				DimenEdit_xpm,			cmd_edt_dimension,	1, 17, 0},
+		{TABLE_SPACE,					NULL,				NULL,					NULL ,				1, 17, 0},
 
-		{_("NC Drawing"),				NULL,				CamNcDraw_xpm,			cmd_NcDraw,			1, 17, 0},
-		{NULL,							NULL, 				NULL,					NULL,				1, 18, 0}
+		{_("NC Drawing"),				NULL,				CamNcDraw_xpm,			cmd_NcDraw,			1, 18, 0},
+		{NULL,							NULL, 				NULL,					NULL,				1, 19, 0}
 	};
 	GtkWidget *table_toolbar;
 
@@ -238,6 +240,25 @@ void table_append_buttons(GtkWidget *container, GtkWidget *toolbar, struct Table
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
 	
+	/* Cancel */
+	pixmap = gdk_pixmap_create_from_xpm_d(toolbar->window, 
+				 &mask, 
+				 &toolbar->style->bg[GTK_STATE_NORMAL],
+				 (gchar **)Cancel_xpm);
+	image = gtk_image_new_from_pixmap(pixmap, mask);
+	
+	//image = gtk_image_new_from_stock (GTK_STOCK_STOP, GTK_ICON_SIZE_SMALL_TOOLBAR);
+
+	button = gtk_button_new();
+	gtk_button_set_image(GTK_BUTTON(button), image);
+	gtk_widget_set_size_request(button, (TOOLBAR_ICON_SIZE * 2) + 2, TOOLBAR_ICON_SIZE);
+	gtk_table_attach (	GTK_TABLE(toolbar), button, 0, 2, 0, 1, 0, 0, 1, 1);
+	tooltips = gtk_tooltips_new();
+	gtk_tooltips_set_tip(tooltips, button, _("Cancel"), _("Cancel"));
+	g_signal_connect (G_OBJECT(button), "clicked", G_CALLBACK(cmd_all_cancel), NULL);
+	gtk_widget_show (image);
+	gtk_widget_show (button);
+	
 	
 	/* ツールバーにItem1をもとにボタンを追加 */
 	while (Item->tooltips != NULL) {
@@ -265,7 +286,7 @@ void table_append_buttons(GtkWidget *container, GtkWidget *toolbar, struct Table
 		
 		button = gtk_button_new();
 		gtk_button_set_image(GTK_BUTTON(button), image);
-		gtk_widget_set_size_request(button, TLLOBAR_ICON_SIZE, TLLOBAR_ICON_SIZE);
+		gtk_widget_set_size_request(button, TOOLBAR_ICON_SIZE, TOOLBAR_ICON_SIZE);
 		
 		gtk_table_attach (	GTK_TABLE(toolbar), 
 							button, 
