@@ -1,5 +1,5 @@
 /* ====================================================================
- * ===  Copyright (C) 1998-2006 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  * 
  *    Project              : SagCAD
@@ -9,11 +9,11 @@
  *    ----------------------------------
  * 
  *    License              : GNU General Public License (GPL)
- *    Copyright            : (C) 1998-2006 by Yutaka Sagiya
+ *    Copyright            : (C) 1998-2007 by Yutaka Sagiya
  *    email                : kappa@a6s.highway.ne.jp
  *                         : yutaka@sagiya.com
  *    Begin                : 2003/02/17
- *    Last                 : 2006/05/25
+ *    Last                 : 2007/11/08
  * ====================================================================
  */
 #ifndef __TYPES_H__
@@ -28,16 +28,16 @@ extern "C" {
 
 
 /* -------------------------------------------------------
- * 1 :   (struct #define etc)
+ * 1 : 前処理  (struct #define etc)
  * -------------------------------------------------------
  */
 
 struct _LAYER {
-	char name[31];	/* 쥤䡼̾ */
-	int draw;		/* 0:ɽ    1:ɽ */
-	int style;		/* 쥤䡼 */
-	int color;		/* 쥤䡼ο */
-	int data;		/* 0:ǡʤ    1:ǡ */
+	char name[31];	/* レイヤー名 */
+	int draw;		/* 0:非表示    1:表示 */
+	int style;		/* レイヤーの線種 */
+	int color;		/* レイヤーの色 */
+	int data;		/* 0:データなし    1:データあり */
 };
 typedef struct _LAYER LAYER;
 
@@ -99,7 +99,7 @@ typedef struct _SAG_FONT_LIST_INFO SAG_FONT_LIST_INFO;
  */
 struct _CAD {
 	int layer;
-	int code;		/* 0  1ľ  2߸  3 */
+	int code;		/* 0：点  1：直線  2：円弧  3：円 */
 	int style;
 	long color;
 	double sx;
@@ -109,7 +109,7 @@ struct _CAD {
 	double cx;
 	double cy;
 	double r ;
-	int OnScreen; /* (1:ɽ  2:ɽ)  0:  1: */
+	int OnScreen; /* (1:表示  2:不表示)  0:正  1:始点終点逆 */
 };
 typedef struct _CAD CAD;
 
@@ -134,23 +134,23 @@ typedef struct _CAD_LIST_INFO CAD_LIST_INFO;
  */
 struct _ASSISTANCE {
 	/* 
-	 * defin  ()
+	 * defin  補助線の定義(部品)
 	 * 
-	 * 					0	
-	 * 					1	
-	 * ߸					2	
-	 * 					4	
+	 * 点					0	
+	 * 線					1	
+	 * 円弧					2	
+	 * 円					4	
 	 * 
-	 * ()		10	LineEndArrow				+0:Τ  +1:
-	 * ξü()		20	LineBothArrow				+0:Τ  +1:
-	 * ξü˵()		30	LineBothConverseArrow		+0:Τ  +1:
+	 * 終点に矢印(線)		10	LineEndArrow				+0:矢印のみ  +1:矢印と線
+	 * 両端に矢印(線)		20	LineBothArrow				+0:矢印のみ  +1:矢印と線
+	 * 両端に逆矢印(線)		30	LineBothConverseArrow		+0:矢印のみ  +1:矢印と線
 	 * 
-	 * (߸)		40	ArcStartArrow				+0:Τ  +1:ȱ߸
-	 * (߸)		50	ArcEndArrow					+0:Τ  +1:ȱ߸
-	 * ξü(߸)		60	ArcBothArrow				+0:Τ  +1:ȱ߸
+	 * 始点に矢印(円弧)		40	ArcStartArrow				+0:矢印のみ  +1:矢印と円弧
+	 * 終点に矢印(円弧)		50	ArcEndArrow					+0:矢印のみ  +1:矢印と円弧
+	 * 両端に矢印(円弧)		60	ArcBothArrow				+0:矢印のみ  +1:矢印と円弧
 	 * 
-	 * 				70	AssistanceLine				Start:з   End:бĹ
-	 * ()αĹ	80	LineEndExtension
+	 * 補助線				70	AssistanceLine				Start:引出隙間   End:引出延長
+	 * (矢印)補助線の延長	80	LineEndExtension
 	 * 						(LineStartExtension)
 	 * 						(LineBothExtension)
 	 */
@@ -172,7 +172,7 @@ struct _TEXT {
 
 	double	SearchPointX;
 	double	SearchPointY;
-	int		StartPoint;		/* ʸν񤭽Ф */
+	int		StartPoint;		/* 文字の書き出し位置 */
 	float	FontHeight;		
 	float	FontSpace;		
 	float	Angle;
@@ -191,7 +191,7 @@ struct _DIMENSION {
 	long	Assist_color;
 
 	int		Type;
-	int		DrawType;		/* 0:̼ܼ	1:ꥵ	2:ɽ */
+	int		DrawType;		/* 0:縮尺実寸	1:固定サイズ	2:実寸表示 */
 
 	char	Text[256];		
 	char	UpperText[20];	
@@ -207,17 +207,17 @@ struct _DIMENSION {
 	float	Angle;
 	double	SearchPointX;
 	double	SearchPointY;
-	int		StartPoint;		/* ʸν񤭽Ф */
+	int		StartPoint;		/* 文字の書き出し位置 */
 
 	/* -------------------------------------------
-	 * ʿֹ碌
+	 * 水平位置合わせ
 	 * 0:Left  
 	 * 1:Center  
 	 * 2:Right 
 	 */
 	int FitPointX;
 	/* -------------------------------------------
-	 * ľֹ碌
+	 * 垂直位置合わせ
 	 * 0:BaseLine  
 	 * 1:BaseLine + FontOverLineSpace  
 	 * 2:Center  
@@ -244,7 +244,7 @@ struct _DIMENSION_CULC {
 typedef struct _DIMENSION_CULC DIMENSION_CULC;
 
 
-/* ˡꥹ */
+/* 寸法リスト */
 struct _DIMENSION_LIST {
 	DIMENSION *dimension;
 	struct _DIMENSION_LIST *next;
@@ -252,7 +252,7 @@ struct _DIMENSION_LIST {
 typedef struct _DIMENSION_LIST DIMENSION_LIST;
 
 
-/* ˡꥹȾ */
+/* 寸法リスト情報 */
 struct _DIMENSION_LIST_INFO {
 	DIMENSION_LIST *head;
 	DIMENSION_LIST *tail;
@@ -265,18 +265,18 @@ typedef struct _DIMENSION_LIST_INFO DIMENSION_LIST_INFO;
  * ELLIPSE
  */
 struct _ELLIPSE {
-	int code;		/* 0:ʱ    1:ʱ߸ */
+	int code;		/* 0:楕円    1:楕円弧 */
 	int layer;
 	long color;
 	int style;
 
-	double cx;		/* 濴 */
-	double cy;		/* 濴 */
-	double dx;		/* Ĺΰ֣(濴а) */
-	double dy;		/* Ĺΰ֣(濴а) */
-	double k;		/* ûΡ */
-	double sa;		/* ϳ */
-	double ea;		/* λ */
+	double cx;		/* 中心Ｘ */
+	double cy;		/* 中心Ｙ */
+	double dx;		/* 長軸の位置Ｘ(中心からの相対位置) */
+	double dy;		/* 長軸の位置Ｙ(中心からの相対位置) */
+	double k;		/* 短軸の％ */
+	double sa;		/* 開始角 */
+	double ea;		/* 終了角 */
 };
 typedef struct _ELLIPSE ELLIPSE;
 
@@ -328,29 +328,29 @@ typedef struct _VERTEX_LIST_INFO VERTEX_LIST_INFO;
 struct _POLYLINE {
 	int layer;
 	/* -------------------------------------------
-	 *	8  : ݥ饤
-	 * 16  : ץ饤
-	 * 32  : ¥ץ饤
-	 *(64) : ٥
+	 *	8  : ポリライン
+	 * 16  : スプライン補間
+	 * 32  : ３次Ｂスプライン曲線
+	 *(64) : ベジェ曲線
 	 */
 	int code;
-	/*  */
+	/* 線種 */
 	int style;
-	/*  */
+	/* 色 */
 	long color;
-	/* ʬ */
+	/* 分割数 */
 	int split;
-	/* ԥå */
+	/* ピッチ */
 	double pitch;
 	/* -------------------------------------------
-	 * 1 : ĤƤ
+	 * 1 : 閉じている
 	 * 
 	 */
 	int frag;
 
-	/* ĺο */
+	/* 頂点の数 */
 	int index;
-	/* ĺΥǡ */
+	/* 頂点のデータ */
 	VERTEX_LIST_INFO vertex_list_info;
 };
 typedef struct _POLYLINE POLYLINE;
@@ -443,7 +443,7 @@ typedef struct _BLOCK_LIST_INFO BLOCK_LIST_INFO;
 /* -------------------------------------------------------------------
  * UNDO
  */
-union _LPDIAGRAM {				// union ޷
+union _LPDIAGRAM {				// union 型の宣言図形
 	int *Nuru_point;
 	CAD *cad_point;				// 2, 4
 	DIMENSION *dimension_point;	// 3
@@ -455,7 +455,7 @@ union _LPDIAGRAM {				// union ޷
 typedef union _LPDIAGRAM LPDIAGRAM;
 
 
-union _DIAGRAM {				// union 
+union _DIAGRAM {				// union 型の宣言
 	int Nuru;
 	CAD cad;					// 2, 4
 	DIMENSION dimension;		// 3
@@ -470,16 +470,16 @@ typedef union _DIAGRAM DIAGRAM;
 struct _UNDO_LIST {
 	/* ---------------------------------------
 	 * [ type ]
-	 * union ʤΤǡǥǡΥפ狼뤷
-	 * ΥɥꥹȤԽΤɤ줫狼롣
+	 * union なので、これでデータのタイプがわかるし、
+	 * このアンドゥリストが、新規、削除、編集のどれかわかる。
 	 * 11,12,13  :	CAD Data 
 	 * 21,22,23  :	Dimension Data 
 	 */
 	int type;
 	/* ---------------------------------------
 	 * [ index ]
-	 * ޤȤƽΤϡޤȤƽ뤿
-	 * index ͤϡȤȤ 1 󥯥Ȥ롣
+	 * まとめて処理したものは、まとめて処理するために
+	 * index の値は、作業ごとに 1 インクリメントする。
 	 */
 	long index;
 	LPDIAGRAM diagram_point;
@@ -501,7 +501,7 @@ typedef struct _UNDO_LIST_INFO UNDO_LIST_INFO;
  * SELECT
  */
 struct _SELECT {
-	int index;	  /* 0:̵	 1:	 2:޷    3:ˡ	 4:޷ */
+	int index;	  /* 0:無	 1:点情報	 2:図形情報    3:寸法情報	 4:図形情報 */
 	double x;
 	double y;
 	LPDIAGRAM diagram_point;
@@ -529,7 +529,7 @@ typedef struct _SELECT_LIST_INFO SELECT_LIST_INFO;
  */
 struct _CAM {
 	int code;
-	int gcode;	/* ľ߸̡ */
+	int gcode;	/* ０：点　１：直線　２：円弧　３：円 */
 	double sx;
 	double sy;
 	double ex;
@@ -560,16 +560,16 @@ typedef struct _CAM_LIST_INFO CAM_LIST_INFO;
 
 
 /* -------------------------------------------------------
- * 2 : ѿ (global)
+ * 2 : 外部変数 (global)
  * -------------------------------------------------------
  */
 #ifdef    _TYPES_
 #define   GLOBAL
-// 
+// 初期値設定
 #define   GLOBAL_VAL(v)  = (v)
 #else
 #define   GLOBAL	extern
-// ʬ̵
+// 初期値設定の代入部分を無くす
 #define   GLOBAL_VAL(v)  /* */
 #endif
 
@@ -583,7 +583,7 @@ typedef struct _CAM_LIST_INFO CAM_LIST_INFO;
 
 
 /* -------------------------------------------------------
- * 3 : ؿ (Function)
+ * 3 : 外部関数 (Function)
  * -------------------------------------------------------
  */
 
@@ -594,7 +594,7 @@ typedef struct _CAM_LIST_INFO CAM_LIST_INFO;
 #endif /* __cplusplus */
 #endif /* __TYPES_H__ */
 /* ====================================================================
- * ===  Copyright (C) 1998-2006 Yutaka Sagiya. All rights reserved. ===
+ * ===  Copyright (C) 1998-2007 Yutaka Sagiya. All rights reserved. ===
  * ====================================================================
  *    Project              : SagCAD
  *    Description          : CAD/CAM
